<?php
use Configuration;
use Order;
use OrderHistory;

class SmartshipApi
{
    private $module;

    public function __construct($module)
    {
        $this->module = $module;
    }

    public function handleApiRequest($action)
    {
        header('Content-Type: application/json');

        switch ($action) {
            case 'estimare_cost':
                $this->handleEstimareCost();
                break;
            case 'emite_awb':
                $this->handleEmiteAwb();
                break;
            case 'get_judete':
                $this->handleGetJudete();
                break;
            case 'get_localitati':
                $this->handleGetLocalitati();
                break;
            case 'search_localitati':
                $this->handleSearchLocalitati();
                break;
            case 'cancel_awb':
                $this->handleCancelAwb();
                break;
            case 'check_version':
                $this->handleCheckVersion();
                break;
            default:
                echo json_encode(['status' => 404, 'message' => 'Endpoint-ul nu a fost găsit!', 'contact' => 'Va rugam sa ne contactati pe smartship.ro pentru a rezolva problema!']);
                break;
        }
        exit;
    }

    private function handleEstimareCost()
    {
        $json = file_get_contents('php://input');
        $data = json_decode($json);

        if (($data->city === 'Bucuresti' || $data->city === 'bucuresti' || $data->city === 'Bucuresti' || $data->city === 'bucuresti') && $data->sector === "0") {
            echo json_encode([
                'status' => 500,
                'message' => 'Va rugam sa selectati un sector diferit de 0 in Bucuresti.',
                'debug' => [
                    'request_data' => $data
                ]
            ]);
            exit;
        }

        $api_key = Configuration::get('SMARTSHIP_API_KEY');
        $iban = Configuration::get('SMARTSHIP_IBAN');
        $sender_name = Configuration::get('SMARTSHIP_SENDER_NAME');
        $sender_address = Configuration::get('SMARTSHIP_ADDRESS');
        $sender_email = Configuration::get('SMARTSHIP_EMAIL');
        $sender_city = Configuration::get('SMARTSHIP_CITY');
        $sender_phone = Configuration::get('SMARTSHIP_PHONE');
        $sender_sector = Configuration::get('SMARTSHIP_SECTOR');


        // Get county ID for recipient
        $curl = curl_init();
        curl_setopt_array($curl, [
            CURLOPT_URL => "https://api.smartship.ro/geolocation/counties?country=RO",
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => "GET",
            CURLOPT_HTTPHEADER => [
                "X-API-KEY: " . $api_key,
                "X-Platform: PRESTASHOP"
            ],
        ]);

        $response = curl_exec($curl);
        $err = curl_error($curl);
        curl_close($curl);

        if ($err) {
            echo json_encode(['status' => 500, 'message' => 'cURL Error: ' . $err]);
            return;
        }

        $counties = json_decode($response);
        $recipient_county_id = null;
        foreach ($counties->counties as $county) {
            if ($county->county === $data->county) {
                $recipient_county_id = $county->id;
                break;
            }
        }

        if (!$recipient_county_id) {
            echo json_encode([
                'status' => 501,
                'message' => 'Județul destinatarului nu a fost găsit.',
                'county' => $data->county,
                'debug' => [
                    'counties' => $counties,
                    'looking_for' => $data->county,
                    'raw_data' => $data
                ]
            ]);
            return;
        }

        // Get city ID for recipient
        $curl = curl_init();
        curl_setopt_array($curl, [
            CURLOPT_URL => "https://api.smartship.ro/geolocation/cities?county=" . $recipient_county_id,
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => "GET",
            CURLOPT_HTTPHEADER => [
                "X-API-KEY: " . $api_key,
                "X-Platform: PRESTASHOP"
            ],
        ]);

        $response = curl_exec($curl);
        $err = curl_error($curl);
        curl_close($curl);

        if ($err) {
            echo json_encode(['status' => 500, 'message' => 'cURL Error: ' . $err]);
            return;
        }

        $cities = json_decode($response);
        $recipient_city_id = null;
        foreach ($cities->cities as $city) {
            if ($city->city === $data->city) {
                $recipient_city_id = $city->id;
                break;
            }
        }

        if (!$recipient_city_id) {
            echo json_encode([
                'status' => 501,
                'message' => 'Localitatea destinatarului nu a fost găsită.',
                'city' => $data->city,
                'debug' => [
                    'cities' => $cities,
                    'looking_for' => $data->city,
                    'county_id' => $recipient_county_id,
                    'raw_data' => $data
                ]
            ]);
            return;
        }

        // Get county ID for sender
        $curl = curl_init();
        curl_setopt_array($curl, [
            CURLOPT_URL => "https://api.smartship.ro/geolocation/counties?country=RO",
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => "GET",
            CURLOPT_HTTPHEADER => [
                "X-API-KEY: " . $api_key,
                "X-Platform: PRESTASHOP"
            ],
        ]);

        $response = curl_exec($curl);
        $err = curl_error($curl);
        curl_close($curl);

        if ($err) {
            echo json_encode(['status' => 500, 'message' => 'cURL Error: ' . $err]);
            return;
        }

        $counties = json_decode($response);
        $sender_county_id = null;
        foreach ($counties->counties as $county) {
            if ($county->county === Configuration::get('SMARTSHIP_COUNTY')) {
                $sender_county_id = $county->id;
                break;
            }
        }

        // Get city ID for sender
        $curl = curl_init();
        curl_setopt_array($curl, [
            CURLOPT_URL => "https://api.smartship.ro/geolocation/cities?county=" . $sender_county_id,
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => "GET",
            CURLOPT_HTTPHEADER => [
                "X-API-KEY: " . $api_key,
                "X-Platform: PRESTASHOP"
            ],
        ]);

        $response = curl_exec($curl);
        $err = curl_error($curl);
        curl_close($curl);

        if ($err) {
            echo json_encode(['status' => 500, 'message' => 'cURL Error: ' . $err]);
            return;
        }

        $cities = json_decode($response);
        $sender_city_id = null;
        foreach ($cities->cities as $city) {
            if ($city->city === $sender_city) {
                $sender_city_id = $city->id;
                break;
            }
        }

        // Now make the cost estimation request
        $curl = curl_init();
        curl_setopt_array($curl, [
            CURLOPT_URL => "https://api.smartship.ro/cost",
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_ENCODING => "",
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => "POST",
            CURLOPT_POSTFIELDS => json_encode([
                'recipient' => [
                    'name' => $data->name,
                    'address' => $data->address,
                    'email' => $data->email,
                    'city' => (int) $recipient_city_id,
                    'phone' => $data->phone,
                    'sector' => $data->sector ?? '0',
                    'country' => 'RO'
                ],
                'sender' => [
                    'name' => $sender_name,
                    'address' => $sender_address,
                    'email' => $sender_email,
                    'city' => (int) $sender_city_id,
                    'phone' => $sender_phone,
                    'sector' => $sender_sector ?? '0',
                    'country' => 'RO'
                ],
                'content' => [
                    'package_content' => 'Diverse',
                    'parcels' => (int) $data->colete,
                    'weight' => (float) $data->greutate,
                    'cash_on_delivery' => (float) $data->ramburs,
                    'length' => (int) $data->lungime,
                    'width' => (int) $data->latime,
                    'height' => (int) $data->inaltime,
                    'insurance' => false,
                    'iban' => $iban,
                    'open_package' => false
                ]
            ]),
            CURLOPT_HTTPHEADER => [
                "Content-Type: application/json",
                "X-API-KEY: " . $api_key,
                "X-Platform: PRESTASHOP"
            ],
        ]);

        $response = curl_exec($curl);
        $err = curl_error($curl);
        curl_close($curl);

        if ($err) {
            echo json_encode(['status' => 500, 'message' => 'cURL Error: ' . $err]);
            return;
        }

        $response = json_decode($response);
        if ($response->status !== 200) {
            echo json_encode([
                'status' => $response->status,
                'message' => $response->message,
                'error' => $response->message,
                'debug' => [
                    'request_data' => [
                        'recipient_county_id' => $recipient_county_id,
                        'recipient_city_id' => $recipient_city_id,
                        'sender_county_id' => $sender_county_id,
                        'sender_city_id' => $sender_city_id
                    ]
                ]
            ]);
            return;
        }

        echo json_encode([
            'status' => 200,
            'message' => 'Estimarea costului a fost efectuată.',
            'response' => $response,
            'debug' => [
                'request_data' => [
                    'recipient_county_id' => $recipient_county_id,
                    'recipient_city_id' => $recipient_city_id,
                    'sender_county_id' => $sender_county_id,
                    'sender_city_id' => $sender_city_id
                ]
            ]
        ]);
    }

    private function handleEmiteAwb()
    {
        try {
            error_log("Smartship AWB: Starting AWB generation");

            $json = file_get_contents('php://input');
            if (!$json) {
                error_log("Smartship AWB Error: No input data received");
                throw new Exception('No input data received');
            }
            error_log("Smartship AWB: Received input data: " . $json);

            $data = json_decode($json);
            if (json_last_error() !== JSON_ERROR_NONE) {
                error_log("Smartship AWB Error: Invalid JSON input - " . json_last_error_msg());
                throw new Exception('Invalid JSON input: ' . json_last_error_msg());
            }

            $api_key = Configuration::get('SMARTSHIP_API_KEY');
            if (!$api_key) {
                error_log("Smartship AWB Error: API key not configured");
                throw new Exception('API key not configured');
            }
            error_log("Smartship AWB: Using API key: " . substr($api_key, 0, 4) . '...');

            $iban = Configuration::get('SMARTSHIP_IBAN');
            $sender_name = Configuration::get('SMARTSHIP_SENDER_NAME');
            $sender_address = Configuration::get('SMARTSHIP_ADDRESS');
            $sender_email = Configuration::get('SMARTSHIP_EMAIL');
            $sender_city = Configuration::get('SMARTSHIP_CITY');
            $sender_phone = Configuration::get('SMARTSHIP_PHONE');
            $sender_sector = Configuration::get('SMARTSHIP_SECTOR');
            $sender_county = Configuration::get('SMARTSHIP_COUNTY');

            // Get county ID for recipient
            $curl = curl_init();
            curl_setopt_array($curl, [
                CURLOPT_URL => "https://api.smartship.ro/geolocation/counties?country=RO",
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                CURLOPT_CUSTOMREQUEST => "GET",
                CURLOPT_HTTPHEADER => [
                    "X-API-KEY: " . $api_key,
                    "X-Platform: PRESTASHOP"
                ],
            ]);

            $response = curl_exec($curl);
            $err = curl_error($curl);
            curl_close($curl);

            if ($err) {
                throw new Exception('cURL Error getting counties: ' . $err);
            }

            $counties = json_decode($response);
            if (json_last_error() !== JSON_ERROR_NONE) {
                throw new Exception('Invalid JSON response from counties API: ' . json_last_error_msg());
            }

            $recipient_county_id = null;
            $sender_county_id = null;

            foreach ($counties->counties as $county) {
                if ($county->county === $data->county) {
                    $recipient_county_id = $county->id;
                }
                if ($county->county === $sender_county) {
                    $sender_county_id = $county->id;
                }
            }

            if (!$recipient_county_id) {
                throw new Exception('Județul destinatarului nu a fost găsit: ' . $data->county);
            }

            if (!$sender_county_id) {
                throw new Exception('Județul expeditorului nu a fost găsit: ' . $sender_county);
            }

            // Get city ID for recipient
            $curl = curl_init();
            curl_setopt_array($curl, [
                CURLOPT_URL => "https://api.smartship.ro/geolocation/cities?county=" . $recipient_county_id,
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                CURLOPT_CUSTOMREQUEST => "GET",
                CURLOPT_HTTPHEADER => [
                    "X-API-KEY: " . $api_key,
                    "X-Platform: PRESTASHOP"
                ],
            ]);

            $response = curl_exec($curl);
            $err = curl_error($curl);
            curl_close($curl);

            if ($err) {
                throw new Exception('cURL Error getting recipient cities: ' . $err);
            }

            $cities = json_decode($response);
            if (json_last_error() !== JSON_ERROR_NONE) {
                throw new Exception('Invalid JSON response from cities API: ' . json_last_error_msg());
            }

            $recipient_city_id = null;
            foreach ($cities->cities as $city) {
                if ($city->city === $data->city) {
                    $recipient_city_id = $city->id;
                    break;
                }
            }

            if (!$recipient_city_id) {
                throw new Exception('Localitatea destinatarului nu a fost găsită: ' . $data->city);
            }

            // Get city ID for sender
            $curl = curl_init();
            curl_setopt_array($curl, [
                CURLOPT_URL => "https://api.smartship.ro/geolocation/cities?county=" . $sender_county_id,
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                CURLOPT_CUSTOMREQUEST => "GET",
                CURLOPT_HTTPHEADER => [
                    "X-API-KEY: " . $api_key,
                    "X-Platform: PRESTASHOP"
                ],
            ]);

            $response = curl_exec($curl);
            $err = curl_error($curl);
            curl_close($curl);

            if ($err) {
                throw new Exception('cURL Error getting sender cities: ' . $err);
            }

            $cities = json_decode($response);
            if (json_last_error() !== JSON_ERROR_NONE) {
                throw new Exception('Invalid JSON response from sender cities API: ' . json_last_error_msg());
            }

            $sender_city_id = null;
            foreach ($cities->cities as $city) {
                if ($city->city === $sender_city) {
                    $sender_city_id = $city->id;
                    break;
                }
            }

            if (!$sender_city_id) {
                throw new Exception('Localitatea expeditorului nu a fost găsită: ' . $sender_city);
            }

            // Now make the AWB request
            $curl = curl_init();
            $requestData = [
                'recipient' => [
                    'name' => $data->name,
                    'address' => $data->address,
                    'email' => $data->email,
                    'city' => (int) $recipient_city_id,
                    'phone' => $data->phone,
                    'country' => 'RO',
                    'sector' => $data->sector ?? '0'
                ],
                'sender' => [
                    'name' => $sender_name,
                    'address' => $sender_address,
                    'email' => $sender_email,
                    'city' => (int) $sender_city_id,
                    'phone' => $sender_phone,
                    'country' => 'RO',
                    'sector' => $sender_sector ?? '0'
                ],
                'content' => [
                    'package_content' => 'Diverse',
                    'parcels' => (int) $data->colete,
                    'weight' => (float) $data->greutate,
                    'cash_on_delivery' => (float) $data->ramburs,
                    'length' => (int) $data->lungime,
                    'width' => (int) $data->latime,
                    'height' => (int) $data->inaltime,
                    'insurance' => 0,
                    'iban' => $iban,
                    'open_package' => 0,
                    'order_id' => isset($data->order_id) ? (string) $data->order_id : '',
                    'curier_preferat' => 0
                ],
                'courier_id' => (int) $data->courier_id
            ];

            curl_setopt_array($curl, [
                CURLOPT_URL => "https://api.smartship.ro/awb/new",
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_ENCODING => "",
                CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                CURLOPT_CUSTOMREQUEST => "POST",
                CURLOPT_POSTFIELDS => json_encode($requestData),
                CURLOPT_HTTPHEADER => [
                    "Content-Type: application/json",
                    "X-API-KEY: " . $api_key,
                    "X-Platform: PRESTASHOP"
                ],
            ]);

            // Before making the final AWB request
            error_log("Smartship AWB: Making AWB request with data: " . json_encode($requestData));

            $response = curl_exec($curl);
            $err = curl_error($curl);
            $httpCode = curl_getinfo($curl, CURLINFO_HTTP_CODE);
            curl_close($curl);

            error_log("Smartship AWB: Response HTTP code: " . $httpCode);
            error_log("Smartship AWB: Raw response: " . $response);

            if ($err) {
                error_log("Smartship AWB Error: cURL Error creating AWB - " . $err);
                throw new Exception('cURL Error creating AWB: ' . $err);
            }

            if (!$response) {
                error_log("Smartship AWB Error: Empty response from AWB API");
                throw new Exception('Empty response from AWB API');
            }

            $responseData = json_decode($response);
            if (json_last_error() !== JSON_ERROR_NONE) {
                error_log("Smartship AWB Error: Invalid JSON response from AWB API - " . json_last_error_msg() . ". Raw response: " . $response);
                throw new Exception('Invalid JSON response from AWB API: ' . json_last_error_msg() . '. Raw response: ' . $response);
            }

            if ($responseData->status !== 200) {
                error_log("Smartship AWB Error: AWB API Error - " . ($responseData->message ?? 'Unknown error'));
                throw new Exception('AWB API Error: ' . ($responseData->message ?? 'Unknown error'));
            }

            error_log("Smartship AWB: Successfully generated AWB: " . $responseData->awb);

            // Update order with AWB information
            if (isset($data->order_id)) {
                try {
                    $order = new Order($data->order_id);
                    $order->setWsShippingNumber($responseData->awb);

                    // Add order history (status update and/or message)
                    $history = new OrderHistory();
                    $history->id_order = (int) $order->id;
                    // Set a status if you want, e.g. $history->changeIdOrderState($id_order_state, $order->id);
                    // Add a message
                    $history->addWithemail(
                        true, // send email
                        [
                            'message' => "AWB " . $responseData->awb . " emis prin SmartShip la curierul " . $responseData->courier_name
                        ]
                    );
                    $order->save();
                    error_log("Smartship AWB: Successfully updated order " . $data->order_id);
                } catch (Exception $e) {
                    error_log("Smartship AWB Error updating order: " . $e->getMessage());
                }
            }

            $response = [
                'status' => 200,
                'message' => 'AWB-ul a fost emis.',
                'awb' => $responseData->awb,
                'cost' => $responseData->cost,
                'courier_name' => $responseData->courier_name
            ];

            error_log("Smartship AWB: Preparing to send success response: " . json_encode($response));
            error_log("Smartship AWB: Setting HTTP response code to 200");
            http_response_code(200);
            error_log("Smartship AWB: Setting Content-Type header");
            header('Content-Type: application/json');
            error_log("Smartship AWB: Sending response");
            echo json_encode($response);
            error_log("Smartship AWB: Response sent, calling exit");
            exit;

        } catch (Exception $e) {
            error_log("Smartship AWB Error: " . $e->getMessage());
            error_log("Smartship AWB Error trace: " . $e->getTraceAsString());
            error_log("Smartship AWB: Setting HTTP response code to 500");
            http_response_code(500);
            error_log("Smartship AWB: Setting Content-Type header");
            header('Content-Type: application/json');
            error_log("Smartship AWB: Sending error response");
            echo json_encode([
                'status' => 500,
                'message' => $e->getMessage(),
                'error' => $e->getMessage()
            ]);
            error_log("Smartship AWB: Error response sent, calling exit");
            exit;
        }
    }

    private function handleGetJudete()
    {
        $api_key = Configuration::get('SMARTSHIP_API_KEY');
        $jud_sel = null;

        if (isset($_GET['judet_selectat']) && strlen($_GET['judet_selectat']) >= 1 && strlen($_GET['judet_selectat']) <= 2) {
            $curl = curl_init();
            curl_setopt_array($curl, [
                CURLOPT_URL => "https://api.smartship.ro/geolocation/counties-short/" . $_GET['judet_selectat'],
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_ENCODING => "",
                CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                CURLOPT_CUSTOMREQUEST => "GET",
                CURLOPT_HTTPHEADER => [
                    "X-API-KEY: " . $api_key,
                    "X-Platform: PRESTASHOP"
                ],
            ]);

            $response = curl_exec($curl);
            $err = curl_error($curl);
            curl_close($curl);

            if (!$err) {
                $res_jud = json_decode($response);
                $jud_sel = $res_jud->county->id;
            }
        }

        $curl = curl_init();
        curl_setopt_array($curl, [
            CURLOPT_URL => "https://api.smartship.ro/geolocation/counties",
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_ENCODING => "",
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => "GET",
            CURLOPT_HTTPHEADER => [
                "X-API-KEY: " . $api_key,
                "X-Platform: PRESTASHOP"
            ],
        ]);

        $response = curl_exec($curl);
        $err = curl_error($curl);
        curl_close($curl);

        if ($err) {
            echo json_encode(['status' => 500, 'message' => 'cURL Error: ' . $err]);
            return;
        }

        $res = json_decode($response);
        echo json_encode([
            'status' => 200,
            'jud_sel' => $jud_sel,
            'judete' => $res->counties
        ]);
    }

    private function handleGetLocalitati()
    {
        $api_key = Configuration::get('SMARTSHIP_API_KEY');
        $locsel = '';

        if (isset($_GET['selected_localitate']) && strlen($_GET['selected_localitate']) > 2) {
            $locsel = urlencode(SmartshipUtils::normalizeChars($_GET['selected_localitate']));
        }

        if (in_array($locsel, ['Sector+1', 'Sector+2', 'Sector+3', 'Sector+4', 'Sector+5', 'Sector+6'])) {
            $locsel = 'Bucuresti';
        }

        $curl = curl_init();
        curl_setopt_array($curl, [
            CURLOPT_URL => "https://api.smartship.ro/geolocation/cities?county=" . $_GET['county'] . '&loc_sel=' . $locsel,
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_ENCODING => "",
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => "GET",
            CURLOPT_HTTPHEADER => [
                "X-API-KEY: " . $api_key,
                "X-Platform: PRESTASHOP"
            ],
        ]);

        $response = curl_exec($curl);
        $err = curl_error($curl);
        curl_close($curl);

        if ($err) {
            echo json_encode(['status' => 500, 'message' => 'cURL Error: ' . $err]);
            return;
        }

        $res = json_decode($response);
        echo json_encode([
            'status' => 200,
            'orase' => $res->cities,
            'city_selected' => $res->city_selected
        ]);
    }

    private function handleSearchLocalitati()
    {
        $search = isset($_GET['search']) ? trim($_GET['search']) : '';

        if (empty($search) || strlen($search) < 2) {
            echo json_encode([
                'status' => 400,
                'message' => 'Căutarea trebuie să aibă cel puțin 2 caractere.'
            ]);
            return;
        }

        $search = urlencode($search);
        $url = "https://prestashop.smartship-delivery.ro/app/api/get-locatii.php?search=" . $search;

        $curl = curl_init();
        curl_setopt_array($curl, [
            CURLOPT_URL => $url,
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_TIMEOUT => 10,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => "GET",
            CURLOPT_HTTPHEADER => [
                "Content-Type: application/json"
            ],
        ]);

        $response = curl_exec($curl);
        $err = curl_error($curl);
        $httpCode = curl_getinfo($curl, CURLINFO_HTTP_CODE);
        curl_close($curl);

        if ($err) {
            echo json_encode([
                'status' => 500,
                'message' => 'Eroare la comunicarea cu serverul de locații: ' . $err
            ]);
            return;
        }

        if ($httpCode !== 200) {
            echo json_encode([
                'status' => $httpCode,
                'message' => 'Eroare la obținerea locațiilor. Cod HTTP: ' . $httpCode
            ]);
            return;
        }

        $locations = json_decode($response, true);

        if (json_last_error() !== JSON_ERROR_NONE) {
            echo json_encode([
                'status' => 500,
                'message' => 'Eroare la parsarea răspunsului de la serverul de locații'
            ]);
            return;
        }

        echo json_encode([
            'status' => 200,
            'locations' => $locations
        ]);
    }

    private function handleCancelAwb()
    {
        try {
            error_log("Smartship Cancel AWB: Starting AWB cancellation");

            $json = file_get_contents('php://input');
            if (!$json) {
                error_log("Smartship Cancel AWB Error: No input data received");
                throw new Exception('No input data received');
            }
            error_log("Smartship Cancel AWB: Received input data: " . $json);

            $data = json_decode($json);
            if (json_last_error() !== JSON_ERROR_NONE) {
                error_log("Smartship Cancel AWB Error: Invalid JSON input - " . json_last_error_msg());
                throw new Exception('Invalid JSON input: ' . json_last_error_msg());
            }

            if (!isset($data->awb) || empty($data->awb)) {
                error_log("Smartship Cancel AWB Error: AWB number not provided");
                throw new Exception('AWB number is required');
            }

            $api_key = Configuration::get('SMARTSHIP_API_KEY');
            if (!$api_key) {
                error_log("Smartship Cancel AWB Error: API key not configured");
                throw new Exception('API key not configured');
            }
            error_log("Smartship Cancel AWB: Using API key: " . substr($api_key, 0, 4) . '...');


            if (isset($data->order_id)) {
                try {
                    $order = new Order($data->order_id);
                    $order->setWsShippingNumber('');

                    // Add order history (status update and/or message)
                    $history = new OrderHistory();
                    $history->id_order = (int) $order->id;
                    $order->save();
                    error_log("Smartship Cancel AWB: Successfully updated order " . $data->order_id);
                } catch (Exception $e) {
                    error_log("Smartship AWB Error updating order: " . $e->getMessage());
                }
            } else {
                // If no order_id provided, try to find order by AWB number
                try {
                    $orders = Order::getOrdersWithInformations();
                    foreach ($orders as $orderInfo) {
                        $order = new Order($orderInfo['id_order']);
                        if ($order->getWsShippingNumber() === $data->awb) {
                            // Remove the shipping number
                            $order->setWsShippingNumber('');

                            // Add order history
                            $history = new OrderHistory();
                            $history->id_order = (int) $order->id;
                            $history->addWithemail(
                                true, // send email
                                [
                                    'message' => "AWB " . $data->awb . " a fost anulat prin SmartShip"
                                ]
                            );
                            $order->save();
                            error_log("Smartship Cancel AWB: Successfully updated order " . $order->id . " - removed shipping number");
                            break;
                        }
                    }
                } catch (Exception $e) {
                    error_log("Smartship Cancel AWB Error finding order by AWB: " . $e->getMessage());
                }
            }

            $response = [
                'status' => 200,
                'message' => 'AWB-ul a fost anulat cu succes.',
                'awb' => $data->awb
            ];

            error_log("Smartship Cancel AWB: Preparing to send success response: " . json_encode($response));
            error_log("Smartship Cancel AWB: Setting HTTP response code to 200");
            http_response_code(200);
            error_log("Smartship Cancel AWB: Setting Content-Type header");
            header('Content-Type: application/json');
            error_log("Smartship Cancel AWB: Sending response");
            echo json_encode($response);
            error_log("Smartship Cancel AWB: Response sent, calling exit");
            exit;

        } catch (Exception $e) {
            error_log("Smartship Cancel AWB Error: " . $e->getMessage());
            error_log("Smartship Cancel AWB Error trace: " . $e->getTraceAsString());
            error_log("Smartship Cancel AWB: Setting HTTP response code to 500");
            http_response_code(500);
            error_log("Smartship Cancel AWB: Setting Content-Type header");
            header('Content-Type: application/json');
            error_log("Smartship Cancel AWB: Sending error response");
            echo json_encode([
                'status' => 500,
                'message' => $e->getMessage(),
                'error' => $e->getMessage()
            ]);
            error_log("Smartship Cancel AWB: Error response sent, calling exit");
            exit;
        }
    }

    private function handleCheckVersion()
    {
        try {
            $current_version = $this->module->version;

            // Make the API call server-side to avoid CORS issues
            $curl = curl_init();
            curl_setopt_array($curl, [
                CURLOPT_URL => "https://prestashop.smartship-delivery.ro/app/api/check-version.php?version=" . urlencode($current_version),
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_TIMEOUT => 10,
                CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                CURLOPT_CUSTOMREQUEST => "GET",
                CURLOPT_HTTPHEADER => [
                    "Content-Type: application/json"
                ],
            ]);

            $response = curl_exec($curl);
            $err = curl_error($curl);
            $httpCode = curl_getinfo($curl, CURLINFO_HTTP_CODE);
            curl_close($curl);

            if ($err) {
                throw new Exception('cURL Error: ' . $err);
            }

            if ($httpCode !== 200) {
                throw new Exception('HTTP Error: ' . $httpCode);
            }

            $data = json_decode($response, true);
            if (json_last_error() !== JSON_ERROR_NONE) {
                throw new Exception('Invalid JSON response: ' . json_last_error_msg());
            }

            // Handle both response formats: single object or array with one object
            $versionData = null;
            if (is_array($data)) {
                if (count($data) > 0 && isset($data[0])) {
                    // Array format: [{"status":"1",...}]
                    $versionData = $data[0];
                } else if (isset($data['status'])) {
                    // Single object format: {"status":"1",...}
                    $versionData = $data;
                }
            }

            if ($versionData && isset($versionData['status'])) {
                echo json_encode([
                    'status' => (int) $versionData['status'],
                    'has_update' => $versionData['status'] === '1' && $versionData['yourVersion'] !== $versionData['latestVersion'],
                    'latest_version' => $versionData['latestVersion'] ?? $current_version,
                    'current_version' => $versionData['yourVersion'] ?? $current_version,
                    'message' => $versionData['message'] ?? ''
                ]);
            } else {
                throw new Exception('Invalid response format from version API');
            }

        } catch (Exception $e) {
            error_log("Smartship Version Check Error: " . $e->getMessage());
            echo json_encode([
                'status' => 500,
                'message' => $e->getMessage(),
                'current_version' => $this->module->version ?? 'unknown'
            ]);
        }
    }
}