<?php
/**
 * SmartshipFormRenderer - PrestaShop module helper
 *
 * NOTE: The Configuration class is provided by PrestaShop. Linter errors for undefined type can be ignored in the context of a real PrestaShop environment.
 */

class SmartshipFormRenderer
{
    private $module;

    public function __construct($module)
    {
        $this->module = $module;
    }

    public function renderBeautifulForm()
    {
        $values = $this->getConfigFormValues();
        $html = '<style>
        .smartship-card { background: #fff; border-radius: 8px; box-shadow: 0 2px 8px rgba(0,0,0,0.04); padding: 32px 24px 24px 24px; margin-bottom: 32px; }
        .smartship-section-title { font-size: 18px; font-weight: 600; margin-bottom: 18px; display: flex; align-items: center; }
        .smartship-section-title i { margin-right: 8px; color: #007bff; }
        .smartship-label { font-weight: 500; margin-bottom: 4px; }
        .smartship-desc { font-size: 12px; color: #888; margin-bottom: 8px; }
        .smartship-form-group { margin-bottom: 18px; }
        .smartship-form-row { display: flex; gap: 24px; }
        .smartship-form-col { flex: 1; min-width: 220px; }
        .smartship-api-link { font-size: 13px; }
        .smartship-api-link i { margin-right: 4px; }
        .smartship-save-btn { margin-top: 24px; }
        @media (max-width: 900px) { .smartship-form-row { flex-direction: column; } }
        </style>';
        $html .= '<form method="post" action="">';
        $html .= '<div class="smartship-card">
            <div class="smartship-section-title"><i class="icon-truck"></i> Configurare Smartship</div>
            <div class="smartship-desc">Configurați integrarea cu Smartship.ro pentru livrări automate.</div>
            <div class="smartship-form-group">
                <label class="smartship-label" for="SMARTSHIP_API_KEY">Cheie API <span style="color:red">*</span></label>
                <input type="text" class="form-control" id="SMARTSHIP_API_KEY" name="SMARTSHIP_API_KEY" value="' . htmlspecialchars($values['SMARTSHIP_API_KEY']) . '" required />
                <div class="smartship-desc smartship-api-link">
                    <i class="icon-info-circle"></i> Puteți găsi cheia API în contul dvs. Smartship la adresa:
                    <a href="https://smartship.ro/contul-meu/setari" target="_blank"><i class="icon-external-link"></i> smartship.ro/contul-meu/setari</a>
                </div>
            </div>
        </div>';
        $html .= '<div class="smartship-card">
            <div class="smartship-section-title"><i class="icon-user"></i> Informații Expeditor</div>
            <div class="smartship-form-row">
                <div class="smartship-form-col">
                    <div class="smartship-form-group">
                        <label class="smartship-label" for="SMARTSHIP_SENDER_NAME">Nume Expeditor <span style="color:red">*</span></label>
                        <input type="text" class="form-control" id="SMARTSHIP_SENDER_NAME" name="SMARTSHIP_SENDER_NAME" value="' . htmlspecialchars($values['SMARTSHIP_SENDER_NAME']) . '" required />
                        <div class="smartship-desc">Numele complet al expeditorului</div>
                    </div>
                    <div class="smartship-form-group">
                        <label class="smartship-label" for="SMARTSHIP_PHONE">Telefon <span style="color:red">*</span></label>
                        <input type="text" class="form-control" id="SMARTSHIP_PHONE" name="SMARTSHIP_PHONE" value="' . htmlspecialchars($values['SMARTSHIP_PHONE']) . '" required />
                        <div class="smartship-desc">Numărul de telefon pentru contact</div>
                    </div>
                    <div class="smartship-form-group">
                        <label class="smartship-label" for="SMARTSHIP_EMAIL">Email <span style="color:red">*</span></label>
                        <input type="email" class="form-control" id="SMARTSHIP_EMAIL" name="SMARTSHIP_EMAIL" value="' . htmlspecialchars($values['SMARTSHIP_EMAIL']) . '" required />
                        <div class="smartship-desc">Adresa de email pentru notificări</div>
                    </div>
                </div>
                <div class="smartship-form-col">
                    <div class="smartship-form-group">
                        <label class="smartship-label" for="SMARTSHIP_COUNTY">Județ <span style="color:red">*</span></label>
                        <input type="text" class="form-control" id="SMARTSHIP_COUNTY" name="SMARTSHIP_COUNTY" value="' . htmlspecialchars($values['SMARTSHIP_COUNTY']) . '" required />
                    </div>
                    <div class="smartship-form-group">
                        <label class="smartship-label" for="SMARTSHIP_CITY">Oraș <span style="color:red">*</span></label>
                        <input type="text" class="form-control" id="SMARTSHIP_CITY" name="SMARTSHIP_CITY" value="' . htmlspecialchars($values['SMARTSHIP_CITY']) . '" required />
                    </div>
                    <div class="smartship-form-group">
                        <label class="smartship-label" for="SMARTSHIP_SECTOR">Sector <span style="color:red">*</span></label>
                        <input type="text" class="form-control" id="SMARTSHIP_SECTOR" name="SMARTSHIP_SECTOR" value="' . htmlspecialchars($values['SMARTSHIP_SECTOR']) . '"  />
                    </div>
                    <div class="smartship-form-group">
                        <label class="smartship-label" for="SMARTSHIP_ADDRESS">Adresă <span style="color:red">*</span></label>
                        <input type="text" class="form-control" id="SMARTSHIP_ADDRESS" name="SMARTSHIP_ADDRESS" value="' . htmlspecialchars($values['SMARTSHIP_ADDRESS']) . '" required />
                    </div>
                </div>
            </div>
        </div>';
        $html .= '<div class="smartship-card">
            <div class="smartship-section-title"><i class="icon-credit-card"></i> Informații Financiare</div>
            <div class="smartship-form-group">
                <label class="smartship-label" for="SMARTSHIP_IBAN">IBAN <span style="color:red">*</span></label>
                <input type="text" class="form-control" id="SMARTSHIP_IBAN" name="SMARTSHIP_IBAN" value="' . htmlspecialchars($values['SMARTSHIP_IBAN']) . '" required />
                <div class="smartship-desc"><i class="icon-info-circle"></i> IBAN-ul pentru rambursări și plăți</div>
            </div>
        </div>';
        $html .= '<button type="submit" name="submit' . $this->module->name . '" class="btn btn-primary btn-lg smartship-save-btn"><i class="icon-save"></i> Salvează</button>';
        $html .= '</form>';
        return $html;
    }

    /**
     * @noinspection PhpUndefinedClassInspection
     */
    public function getConfigFormValues()
    {
        // Configuration is a PrestaShop core class. Ignore linter errors if any.
        if (!class_exists('Configuration')) {
            return [
                'SMARTSHIP_API_KEY' => '',
                'SMARTSHIP_IBAN' => '',
                'SMARTSHIP_SENDER_NAME' => '',
                'SMARTSHIP_PHONE' => '',
                'SMARTSHIP_EMAIL' => '',
                'SMARTSHIP_COUNTY' => '',
                'SMARTSHIP_CITY' => '',
                'SMARTSHIP_SECTOR' => '',
                'SMARTSHIP_ADDRESS' => '',
            ];
        }
        return array(
            'SMARTSHIP_API_KEY' => Configuration::get('SMARTSHIP_API_KEY'),
            'SMARTSHIP_IBAN' => Configuration::get('SMARTSHIP_IBAN'),
            'SMARTSHIP_SENDER_NAME' => Configuration::get('SMARTSHIP_SENDER_NAME'),
            'SMARTSHIP_PHONE' => Configuration::get('SMARTSHIP_PHONE'),
            'SMARTSHIP_EMAIL' => Configuration::get('SMARTSHIP_EMAIL'),
            'SMARTSHIP_COUNTY' => Configuration::get('SMARTSHIP_COUNTY'),
            'SMARTSHIP_CITY' => Configuration::get('SMARTSHIP_CITY'),
            'SMARTSHIP_SECTOR' => Configuration::get('SMARTSHIP_SECTOR'),
            'SMARTSHIP_ADDRESS' => Configuration::get('SMARTSHIP_ADDRESS'),
        );
    }
}