<?php
use Order;
use Customer;
use Address;
use State;

class SmartshipOrderHelper
{
    public static function getReceiverData($orderId)
    {
        $order = new Order($orderId);
        $customer = new Customer($order->id_customer);
        $address = new Address($order->id_address_delivery);
        $receiver_name = $address->firstname . ' ' . $address->lastname;
        $receiver_phone = $address->phone ? $address->phone : $address->phone_mobile;
        $receiver_email = $customer->email;
        $county = ($address->id_state ? State::getNameById($address->id_state) : '');
        $city = $address->city;
        $sector = isset($address->other) ? $address->other : '';
        $full_address = $address->address1;
        return [
            'receiver_name' => $receiver_name,
            'receiver_phone' => $receiver_phone,
            'receiver_email' => $receiver_email,
            'county' => $county,
            'city' => $city,
            'sector' => $sector,
            'full_address' => $full_address,
        ];
    }

    public static function getProductData($orderId)
    {
        $order = new Order($orderId);
        $products = $order->getProducts();
        $total_weight = 0;
        $max_width = 0;
        $max_height = 0;
        $max_depth = 0;
        $product_data_js = [];
        foreach ($products as $product) {
            $qty = (int) $product['product_quantity'];
            for ($i = 0; $i < $qty; $i++) {
                $product_data_js[] = [
                    'name' => $product['product_name'],
                    'weight' => (float) $product['weight'],
                    'width' => (float) $product['width'],
                    'height' => (float) $product['height'],
                    'depth' => (float) $product['depth'],
                ];
            }
            $total_weight += (float) $product['weight'] * $qty;
            $max_width = max($max_width, (float) $product['width']);
            $max_height = max($max_height, (float) $product['height']);
            $max_depth = max($max_depth, (float) $product['depth']);
        }
        $total_weight = round($total_weight, 2);
        $max_width = round($max_width, 2);
        $max_height = round($max_height, 2);
        $max_depth = round($max_depth, 2);
        $colete = 1;
        if ($total_weight < 1)
            $total_weight = 1;
        if ($max_width < 1)
            $max_width = 10;
        if ($max_height < 1)
            $max_height = 10;
        if ($max_depth < 1)
            $max_depth = 10;
        return [
            'product_data_js' => $product_data_js,
            'total_weight' => $total_weight,
            'max_width' => $max_width,
            'max_height' => $max_height,
            'max_depth' => $max_depth,
            'colete' => $colete,
        ];
    }
}