# Documentație Modul Smartship.ro pentru PrestaShop

## Descriere

Modulul Smartship.ro pentru PrestaShop permite integrarea automată cu platforma Smartship.ro pentru generarea și gestionarea AWB-urilor (Air Way Bill) pentru livrări în România. Acest modul oferă o soluție completă pentru expedierea comenzilor prin intermediul curierilor disponibili pe platforma Smartship.

## Caracteristici

- **Generare automată AWB**: Crearea automată a AWB-urilor pentru comenzile PrestaShop
- **Integrare cu curieri**: Suport pentru toți curierii disponibili pe Smartship.ro
- **Calculare costuri**: Estimarea automată a costurilor de livrare
- **Tracking integrat**: Urmărirea comenzilor direct din panoul de administrare
- **Configurare simplă**: Interfață intuitivă pentru configurarea expeditorului
- **Suport ramburs**: Gestionarea automată a rambursurilor

## Cerințe Sistem

- PrestaShop 1.7.x sau mai nou
- PHP 7.4 sau mai nou
- Extensia cURL activată
- Acces la internet pentru comunicarea cu API-ul Smartship

## Instalare

### Pasul 1: Descărcarea Modulului

1. Descărcați fișierul `smartship.php` din repository-ul oficial
2. Creați un folder numit `smartship` în directorul `/modules/` al instalării PrestaShop
3. Plasați fișierul `smartship.php` în folderul `/modules/smartship/`

### Pasul 2: Instalarea din Panoul de Administrare

1. Accesați panoul de administrare PrestaShop
2. Navigați la **Modules > Module Manager**
3. Căutați "Smartship" în lista de module
4. Apăsați butonul **Install**

### Pasul 3: Configurarea Modulului

#### Configurarea Județelor (IMPORTANT!)

**Înainte de a configura modulul Smartship, trebuie să configurați județele în PrestaShop:**

1. Accesați **International > Locations**
2. Găsiți **Romania** în lista de țări și apăsați **Edit**
3. În secțiunea **Address format**, adăugați: `State:name`
4. Salvați modificările
5. Asigurați-vă că coloana pentru județe/state este activată

Această configurație este **obligatorie** pentru ca modulul să funcționeze corect, deoarece modulul folosește informațiile despre județe pentru a identifica destinația livrării.

#### Configurarea Modulului Smartship

1. După instalare, accesați **Modules > Module Manager**
2. Găsiți modulul Smartship și apăsați **Configure**
3. Completați toate câmpurile obligatorii:

##### Configurare API

- **Cheie API**: Obțineți cheia API de la [smartship.ro/contul-meu/setari](https://smartship.ro/contul-meu/setari)

##### Informații Expeditor

- **Nume Expeditor**: Numele complet al expeditorului
- **Telefon**: Numărul de telefon pentru contact
- **Email**: Adresa de email pentru notificări
- **Județ**: Județul expeditorului
- **Oraș**: Orașul expeditorului
- **Sector**: Sectorul (pentru București)
- **Adresă**: Adresa completă a expeditorului

##### Informații Financiare

- **IBAN**: IBAN-ul pentru rambursări și plăți

4. Apăsați **Salvează** pentru a păstra configurația

## Utilizare

### Generarea AWB-ului pentru o Comandă

1. Accesați **Orders > Orders** din panoul de administrare
2. Deschideți comanda pentru care doriți să generați AWB-ul
3. În secțiunea de jos a paginii, veți găsi panoul **Smartship.ro AWB Generator**
4. Apăsați butonul **Generează AWB**

### Procesul de Generare AWB

1. **Completarea datelor**: Modulul va pre-completa automat datele destinatarului din comanda PrestaShop
2. **Calcularea costurilor**: Apăsați **Calculează Cost** pentru a vedea opțiunile de curieri disponibile
3. **Selectarea curierului**: Alegeți curierul dorit din lista afișată
4. **Generarea AWB-ului**: Apăsați **Generează AWB** pentru a crea AWB-ul

### Vizualizarea AWB-ului Generat

După generarea cu succes a AWB-ului:

- AWB-ul va fi afișat în panoul de comandă
- Veți avea acces la butoanele:
  - **Printează AWB**: Pentru tipărirea AWB-ului
  - **Vezi AWB**: Pentru vizualizarea AWB-ului pe Smartship.ro
  - **Tracking**: Pentru urmărirea coletului

### Istoricul Tracking-ului

Modulul afișează automat istoricul tracking-ului pentru AWB-urile generate, inclusiv:

- Data și ora fiecărui eveniment
- Descrierea evenimentului
- Localitatea unde s-a produs evenimentul

## Configurare Avansată

### Hook-uri Disponibile

Modulul folosește următoarele hook-uri PrestaShop:

- `displayAdminOrderMainBottom`: Afișează panoul AWB în pagina de comandă
- `actionFrontControllerSetMedia`: Încarcă resursele JavaScript necesare

### API Endpoints

Modulul expune următoarele endpoint-uri API:

- `estimare_cost`: Calculează costurile de livrare
- `emite_awb`: Generează AWB-ul
- `get_judete`: Obține lista de județe
- `get_localitati`: Obține lista de localități

## Depanare

### Probleme Comune

#### 1. Eroare "API key not configured"

**Soluție**: Verificați că ați configurat cheia API în setările modulului

#### 2. Eroare "Județul destinatarului nu a fost găsit"

**Soluție**: Verificați că numele județului din comanda PrestaShop corespunde cu numele din baza de date Smartship

#### 3. Eroare "Localitatea destinatarului nu a fost găsită"

**Soluție**: Verificați că numele localității din comanda PrestaShop corespunde cu numele din baza de date Smartship

#### 4. AWB-ul nu se generează

**Soluție**:

- Verificați că toate datele expeditorului sunt completate corect
- Verificați că IBAN-ul este valid
- Verificați că aveți credit suficient în contul Smartship

### Log-uri de Debug

Modulul generează log-uri detaliate pentru depanare. Acestea pot fi găsite în:

- Log-urile PHP ale serverului
- Log-urile PrestaShop (dacă sunt activate)

### Testarea Integrării

Pentru a testa integrarea:

1. Creați o comandă de test în PrestaShop
2. Completați datele de livrare cu o adresă validă din România
3. Încercați să generați un AWB pentru comanda de test
4. Verificați că AWB-ul este generat cu succes

## Suport Tehnic

Pentru suport tehnic și întrebări:

- **Website**: [smartship.ro](https://smartship.ro)
- **Email**: support@smartship.ro
- **Telefon**: +40 XXX XXX XXX

## Actualizări

Pentru a actualiza modulul:

1. Descărcați versiunea nouă
2. Înlocuiți fișierul `smartship.php` existent
3. Dezinstalați și reinstalați modulul din panoul de administrare

## Licență

Acest modul este furnizat sub licența GPL v3. Pentru mai multe detalii, consultați fișierul LICENSE.

## Changelog

### Versiunea 1.0.0

- Lansare inițială
- Suport pentru generarea AWB-urilor
- Integrare cu toți curierii Smartship
- Interfață de configurare intuitivă
- Tracking integrat
- Suport pentru rambursuri
