<?php
use Configuration;
use Tools;
use Order;
require_once __DIR__ . '/classes/SmartshipFormRenderer.php';
require_once __DIR__ . '/classes/SmartshipOrderHelper.php';
require_once __DIR__ . '/classes/SmartshipApi.php';
require_once __DIR__ . '/classes/SmartshipUtils.php';

if (!defined('_PS_VERSION_')) {
  exit;
}

class Smartship extends Module
{
  public function __construct()
  {
    $this->name = 'smartship';
    $this->tab = 'shipping_logistics';
    //get version from config.xml
    $config_file = __DIR__ . '/config.xml';
    if (file_exists($config_file)) {
      $xml = simplexml_load_file($config_file);
      if ($xml && isset($xml->version)) {
        $this->version = (string) $xml->version;
      }
    }

    $this->author = 'Smartship';
    $this->need_instance = 0;
    $this->bootstrap = true;

    parent::__construct();

    $this->displayName = $this->l('Smartship.ro');
    $this->description = $this->l('Integrare Smartship.ro pentru PrestaShop');
    $this->confirmUninstall = $this->l('Sigur doriți să dezinstalați modulul?');
  }

  public function install()
  {
    if (
      !parent::install() ||
      !$this->registerHook('header') ||
      !$this->registerHook('backOfficeHeader') ||
      !$this->registerHook('displayOrderConfirmation') ||
      !$this->registerHook('displayAdminOrderMainBottom') ||
      !$this->registerHook('actionFrontControllerSetMedia') ||
      !Configuration::updateValue('SMARTSHIP_API_KEY', '') ||
      !Configuration::updateValue('SMARTSHIP_IBAN', '') ||
      !Configuration::updateValue('SMARTSHIP_SENDER_NAME', '') ||
      !Configuration::updateValue('SMARTSHIP_PHONE', '') ||
      !Configuration::updateValue('SMARTSHIP_EMAIL', '') ||
      !Configuration::updateValue('SMARTSHIP_COUNTY', '') ||
      !Configuration::updateValue('SMARTSHIP_CITY', '') ||
      !Configuration::updateValue('SMARTSHIP_SECTOR', '') ||
      !Configuration::updateValue('SMARTSHIP_ADDRESS', '')
    ) {
      return false;
    }
    return true;
  }

  public function uninstall()
  {
    return parent::uninstall() &&
      Configuration::deleteByName('SMARTSHIP_API_KEY') &&
      Configuration::deleteByName('SMARTSHIP_IBAN') &&
      Configuration::deleteByName('SMARTSHIP_SENDER_NAME') &&
      Configuration::deleteByName('SMARTSHIP_PHONE') &&
      Configuration::deleteByName('SMARTSHIP_EMAIL') &&
      Configuration::deleteByName('SMARTSHIP_COUNTY') &&
      Configuration::deleteByName('SMARTSHIP_CITY') &&
      Configuration::deleteByName('SMARTSHIP_SECTOR') &&
      Configuration::deleteByName('SMARTSHIP_ADDRESS');
  }

  public function getContent()
  {
    $output = '';
    if (Tools::isSubmit('submit' . $this->name)) {
      Configuration::updateValue('SMARTSHIP_API_KEY', Tools::getValue('SMARTSHIP_API_KEY'));
      Configuration::updateValue('SMARTSHIP_IBAN', Tools::getValue('SMARTSHIP_IBAN'));
      Configuration::updateValue('SMARTSHIP_SENDER_NAME', Tools::getValue('SMARTSHIP_SENDER_NAME'));
      Configuration::updateValue('SMARTSHIP_PHONE', Tools::getValue('SMARTSHIP_PHONE'));
      Configuration::updateValue('SMARTSHIP_EMAIL', Tools::getValue('SMARTSHIP_EMAIL'));
      Configuration::updateValue('SMARTSHIP_COUNTY', Tools::getValue('SMARTSHIP_COUNTY'));
      Configuration::updateValue('SMARTSHIP_CITY', Tools::getValue('SMARTSHIP_CITY'));
      Configuration::updateValue('SMARTSHIP_SECTOR', Tools::getValue('SMARTSHIP_SECTOR'));
      Configuration::updateValue('SMARTSHIP_ADDRESS', Tools::getValue('SMARTSHIP_ADDRESS'));
      $output .= $this->displayConfirmation($this->l('Setările au fost actualizate cu succes!'));
    }
    $formRenderer = new SmartshipFormRenderer($this);
    return $output . $formRenderer->renderBeautifulForm();
  }

  public function hookDisplayAdminOrderMainBottom($params)
  {
    return $this->hookDisplayAdminOrder($params);
  }

  public function hookDisplayAdminOrder($params)
  {
    error_log('[Smartship AWB DEBUG] hookDisplayAdminOrder called for order: ' . (isset($params['id_order']) ? $params['id_order'] : 'N/A'));
    echo '<pre style="color:red;">[Smartship AWB DEBUG] hookDisplayAdminOrder called for order: ' . (isset($params['id_order']) ? $params['id_order'] : 'N/A') . '</pre>';
    $orderId = $params['id_order'];
    $receiverData = SmartshipOrderHelper::getReceiverData($orderId);
    $productData = SmartshipOrderHelper::getProductData($orderId);
    extract($receiverData);
    extract($productData);
    $product_data_json = json_encode($product_data_js);
    $totals_json = json_encode([
      'total_weight' => $total_weight,
      'max_width' => $max_width,
      'max_height' => $max_height,
      'max_depth' => $max_depth,
      'colete' => $colete
    ]);
    $order = new Order($orderId);
    $ramburs = number_format($order->total_paid, 2, '.', '');

    // Check if AWB/tracking number exists using order carriers
    $order_carriers = $order->getShipping();
    $tracking_number = '';
    if (!empty($order_carriers)) {
      foreach ($order_carriers as $carrier) {
        if (!empty($carrier['tracking_number'])) {
          $tracking_number = $carrier['tracking_number'];
          break;
        }
      }
    }

    if (!empty($tracking_number)) {
      // Fetch AWB details from API
      $awb = $tracking_number;
      $api_key = Configuration::get('SMARTSHIP_API_KEY');
      error_log('[Smartship AWB DEBUG] Checking AWB: ' . $awb);
      echo '<pre style="color:red;">[Smartship AWB DEBUG] Checking AWB: ' . htmlspecialchars($awb) . '</pre>';
      $ch = curl_init();
      curl_setopt_array($ch, [
        CURLOPT_URL => "https://api.smartship.ro/awb/status/" . $awb,
        CURLOPT_RETURNTRANSFER => true,
        CURLOPT_HTTPHEADER => [
          "X-API-KEY: " . $api_key,
          "X-Platform: PRESTASHOP"
        ],
      ]);
      $response = curl_exec($ch);
      $curl_errno = curl_errno($ch);
      $curl_error = curl_error($ch);
      curl_close($ch);
      error_log('[Smartship AWB DEBUG] API response: ' . $response);
      if ($curl_errno) {
        error_log('[Smartship AWB DEBUG] cURL error: ' . $curl_error);
        echo '<pre style="color:red;">[Smartship AWB DEBUG] cURL error: ' . htmlspecialchars($curl_error) . '</pre>';
      }
      echo '<pre style="color:red;">[Smartship AWB DEBUG] API response: ' . htmlspecialchars($response) . '</pre>';
      $awbData = json_decode($response, true);
      if (isset($awbData['status']) && $awbData['status'] == 200) {
        $data = $awbData; // The data is directly in the root
        $html = '<style>
.smartship-awb-details-panel {
    border: 2px solid #28a745;
    background: #fff;
    padding: 28px 24px 18px 24px;
    margin-bottom: 32px;
    max-width: 600px;
    box-shadow: 0 2px 8px rgba(40,167,69,0.07);
}
.smartship-awb-header {
    font-size: 22px;
    font-weight: 700;
    color: #28a745;
    margin-bottom: 18px;
}
.smartship-awb-details-panel b {
    color: #222;
}
.smartship-awb-details-panel .awb-label {
    min-width: 90px;
    display: inline-block;
    color: #222;
}
.smartship-awb-details-panel .awb-actions {
    margin: 18px 0 10px 0;
    display: flex;
    gap: 12px;
    flex-wrap: wrap;
}
.smartship-awb-details-panel .awb-actions a {
    min-width: 120px;
}
.smartship-awb-tracking-history {
    margin-top: 18px;
    background: #f8f8f8;
    border-radius: 6px;
    padding: 12px 16px;
    font-size: 14px;
}
.smartship-awb-tracking-history .tracking-title {
    font-weight: 600;
    margin-bottom: 8px;
    color: #222;
}
.smartship-awb-tracking-history ul {
    padding-left: 0;
    margin: 0;
    list-style: none;
}
.smartship-awb-tracking-history li {
    margin-bottom: 6px;
    line-height: 1.5;
    display: flex;
    align-items: flex-start;
    gap: 10px;
}
.smartship-awb-tracking-history .tracking-date {
    min-width: 110px;
    color: #222;
    font-family: monospace;
}
.smartship-awb-tracking-history .tracking-desc {
    flex: 1;
}
.smartship-awb-tracking-history .tracking-locality {
    color: #888;
    min-width: 60px;
    text-align: right;
}
</style>';
        $html .= '<div class="smartship-awb-details-panel">';
        $html .= '<div class="smartship-awb-header">AWB: <span style="color:#222;">' . htmlspecialchars($data['awb']) . '</span></div>';
        $html .= '<div style="margin-bottom:10px;"><span class="awb-label"><b>Curier:</b></span> ' . htmlspecialchars($data['carrier']) . '</div>';
        $html .= '<div style="margin-bottom:18px;"><span class="awb-label"><b>Status:</b></span> ' . htmlspecialchars($data['awb_status_desc']) . '</div>';
        $html .= '<div class="awb-actions">';
        if ($data['awb_status'] === 10) {
          $html .= '<a href="#" id="smartship-cancel-awb" onclick="cancelAwb(\'' . htmlspecialchars($data['awb']) . '\')" class="btn btn-danger">Sterge AWB</a>';
          $html .= '<script>
            function cancelAwb(awb) {
              console.log("Cancel AWB button clicked");
              console.log("AWB:", awb);
              
              if (!awb) {
                alert("Eroare: AWB-ul nu a fost găsit.");
                return;
              }
              
              if (!confirm("Sigur doriți să anulați AWB-ul " + awb + "? Această acțiune nu poate fi anulată.")) {
                return;
              }
              
              // Show loading state
              document.getElementById("smartship-cancel-awb").innerHTML = "<i class=\"icon-spinner icon-spin\"></i> Se anulează...";
              document.getElementById("smartship-cancel-awb").disabled = true;
              
              fetch("' . $this->context->link->getModuleLink('smartship', 'api', ['action' => 'cancel_awb']) . '", {
                method: "POST",
                headers: {
                  "Content-Type": "application/json",
                },
                body: JSON.stringify({
                  awb: awb,
                  order_id: ' . $params['id_order'] . '
                })
              })
              .then(response => {
                console.log("Cancel AWB Response status:", response.status);
                return response.text().then(text => {
                  console.log("Raw cancel response:", text);
                  try {
                    return text ? JSON.parse(text) : null;
                  } catch (e) {
                    console.error("JSON parse error:", e);
                    throw new Error("Invalid JSON response: " + text);
                  }
                });
              })
              .then(result => {
                if (result && result.status === 200) {
                  alert("AWB-ul " + awb + " a fost anulat cu succes!");
                  location.reload();
                } else {
                  let errorMsg = result ? (result.message || "A apărut o eroare la anularea AWB-ului.") : "Empty response from server";
                  alert("Eroare: " + errorMsg);
                  console.error("Cancel AWB Error:", result);
                }
              })
              .catch(error => {
                alert("A apărut o eroare la comunicarea cu serverul: " + error.message);
                console.error("Cancel AWB Error:", error);
              })
              .finally(() => {
                // Reset button state
                document.getElementById("smartship-cancel-awb").innerHTML = "Sterge AWB";
                document.getElementById("smartship-cancel-awb").disabled = false;
              });
          }
          </script>';
        } else {
          $html .= '<a href="https://smartship.ro/api/' . htmlspecialchars($api_key) . '/print/' . htmlspecialchars($data['awb']) . '" target="_blank" class="btn btn-primary">Printează AWB</a>';
          $html .= '<a href="https://smartship.ro/contul-meu/awb/' . htmlspecialchars($data['awb']) . '" target="_blank" class="btn btn-info">Vezi AWB in contul Smartship</a>';
          $html .= '<a href="' . htmlspecialchars($data['tracking_link']) . '" target="_blank" class="btn btn-success">Tracking</a>';
        }
        $html .= '</div>';
        if (!empty($data['tracking'])) {
          $html .= '<div class="smartship-awb-tracking-history">';
          $html .= '<div class="tracking-title">Istoric tracking:</div>';
          $html .= '<ul>';
          foreach ($data['tracking'] as $event) {
            $html .= '<li>';
            $html .= '<span class="tracking-date">' . htmlspecialchars($event['date']) . '</span>';
            $html .= '<span class="tracking-desc">- ' . htmlspecialchars($event['description']) . '</span>';
            $html .= '<span class="tracking-locality">(' . htmlspecialchars($event['locality']) . ')</span>';
            $html .= '</li>';
          }
          $html .= '</ul>';
          $html .= '</div>';
        }
        $html .= '<div><p>Ai nevoie de ajutor? Contactează-ne la <a href="mailto:office@smartship.ro">office@smartship.ro</a> sau pe <a href="https://smartship.ro">Smartship.ro</a></p></div>';

        $html .= '<div><p>Versiunea: ' . $this->version . ' <span id="smartship-version"></span> </p></div>';
        $html .= '<script>
 function checkVersion() {
            var versionSpan = document.getElementById("smartship-version");
            if (!versionSpan) return;
            
            // Show loading state
            versionSpan.innerHTML = " <span style=\"color: #6c757d; font-style: italic;\">(se verifică...)</span>";
            
            // Use our own API endpoint to check version
            fetch("' . $this->context->link->getModuleLink('smartship', 'api', ['action' => 'check_version']) . '")
              .then(response => response.json())
              .then(data => {
                console.log("Version check data:", data);
                //if data.status is 1,has update is true, if is 0, has update is false
                if (data.status === 1) {              
                  versionSpan.innerHTML = " <span style=\"color: #ff6b35; font-weight: 600;\">🔄 Actualizare disponibilă: " + data.latest_version + ". <br>Descarcă de aici: <a href=\"https://smartship.ro/integrari/prestashop\">aici</a>!</span>";
                } else if (data.status === 0) {
                  versionSpan.innerHTML = " <span style=\"color: #28a745; font-weight: 600;\">✅</span>";
                } else if (data.status === 2) {
                  versionSpan.innerHTML = " <span style=\"color: #6c757d; font-style: italic;\">Versiunea ta este mai nouă decât cea disponibilă. Te rugăm să ne contactezi pentru a te ajuta!</span>";
                }

              })
              .catch(error => {
                console.error("Version check error:", error);
                versionSpan.innerHTML = " <span style=\"color: #6c757d; font-style: italic;\">(verificare eșuată)</span>";
              });
          }
          
          // Run version check when page loads
          checkVersion();
        </script>';
        $html .= '</div>';
        return $html;
      } else {
        error_log('[Smartship AWB DEBUG] AWB details not found or status not 200. Decoded: ' . print_r($awbData, true));
        echo '<pre style="color:red;">[Smartship AWB DEBUG] AWB details not found or status not 200. </pre>';
        // If API fails, show fallback
        return '<div class="panel panel-warning"><div class="panel-heading"><i class="icon-truck"></i> AWB emis: <b>' . htmlspecialchars($awb) . '</b></div><div class="panel-body">Nu s-au putut prelua detaliile AWB-ului.</div></div>';
      }
    }
    // If no AWB, show the modal/button as before
    $awb_modal = '
        <style>
        .smartship-awb-generator-panel {
            border: 1px solid #ebebeb;
            background: #fff;
            padding: 24px;
            margin-bottom: 20px;
        }
        .smartship-awb-generator-panel .panel-content {
            display: flex;
            align-items: center;
            gap: 24px;
        }

        .smartship-awb-generator-panel .text-content {
            flex-grow: 1;
        }
        .smartship-awb-generator-panel .actions .btn {
            white-space: nowrap;
        }
        @media (max-width: 991px) {
            .smartship-awb-generator-panel .panel-content {
                flex-direction: column;
                text-align: center;
            }
            .smartship-awb-generator-panel .actions {
                margin-top: 16px;
            }
        }
        #smartship-awb-modal { display:none; position:fixed; z-index:9999; left:0; top:0; width:100vw; height:100vh; background:rgba(0,0,0,0.4); }
        #smartship-awb-modal .modal-content { 
            background:#fff; 
            border-radius:8px; 
            max-width:1100px; 
            margin:60px auto; 
            padding:32px 24px; 
            position:relative; 
            display:flex; 
            gap:32px; 
            align-items: flex-start;
        }
        #smartship-awb-modal .close { position:absolute; right:16px; top:16px; font-size:24px; cursor:pointer; }
        #smartship-awb-modal input, #smartship-awb-modal select { width:100%; margin-bottom:12px; padding:8px; border-radius:4px; border:1px solid #ccc; }
        #smartship-awb-modal label { font-weight:500; margin-bottom:4px; display:block; }
        #smartship-awb-modal .form-row { display:flex; gap:12px; }
        #smartship-awb-modal .form-row > div { flex:1; }
        #smartship-awb-modal .awb-btn { margin-top:18px; width:100%; }
        #smartship-awb-modal .form-section { 
            flex:1; 
            min-width:340px; 
            max-width: 520px;
        }
        #smartship-awb-modal .form-section form {
            width: 100%;
            max-width: 500px;
        }
        #smartship-awb-modal .couriers-section { 
            flex:1.2; 
            min-width:340px; 
            max-width: 420px;
            margin-top: 0;
        }
        #smartship-awb-modal .courier-card { 
            display: flex;
            align-items: center;
            padding: 16px;
            border: 1px solid #eee;
            border-radius: 8px;
            margin-bottom: 12px;
            cursor: pointer;
            transition: all 0.2s ease;
        }
        #smartship-awb-modal .courier-card:hover {
            border-color: #007bff;
            box-shadow: 0 2px 8px rgba(0,0,0,0.1);
        }
        #smartship-awb-modal .courier-card.selected {
            border-color: #28a745;
            background: #eafbe7;
        }
        #smartship-awb-modal .courier-logo {
            width: 48px;
            height: 48px;
            object-fit: contain;
            margin-right: 16px;
        }
        #smartship-awb-modal .courier-info {
            flex: 1;
        }
        #smartship-awb-modal .courier-name {
            font-weight: 600;
            margin-bottom: 4px;
        }
        #smartship-awb-modal .courier-price {
            color: #28a745;
            font-weight: 600;
            font-size: 18px;
            margin-bottom: 4px;
        }
        #smartship-awb-modal .courier-delivery {
            color: #666;
            font-size: 13px;
        }
        #smartship-awb-modal .loading-spinner {
            display: none;
            text-align: center;
            padding: 32px;
        }
        #smartship-awb-modal .loading-spinner.active {
            display: block;
        }
        #smartship-awb-modal .loading-spinner i {
            font-size: 32px;
            color: #007bff;
            animation: spin 1s linear infinite;
        }
        @keyframes spin {
            0% { transform: rotate(0deg); }
            100% { transform: rotate(360deg); }
        }
        @media (max-width:900px) { 
            #smartship-awb-modal .modal-content { 
                flex-direction: column;
                margin: 20px;
            }
            #smartship-awb-modal .form-section,
            #smartship-awb-modal .couriers-section {
                max-width: 100%;
            }
        }

        #smartship-awb-modal .form-section-inner {
            display: flex;
            justify-content: space-between;
            width: 100%;
        }

        #smartship-awb-modal .form-section form {
        </style>
        <div class="smartship-awb-generator-panel">
            <div class="panel-content">
                <div class="actions">
                    <button type="button" class="btn btn-primary" id="smartship-generate-awb" style="padding: 10px 20px; font-size: 1.1em;">
                        <i class="icon-truck"></i> Generează AWB
                    </button>
                </div>
                <div class="text-content">
                    <h4 style="margin-top: 0; font-size: 1.1em; font-weight: 600;">Genereaza AWB Rapid</h4>
                    <p style="color: #6c757d; margin-bottom: 12px;">
                        Creează automat AWB-uri pentru expediere prin curieri parteneri. 
                        Sistemul calculează costurile, generează documentele necesare și oferă tracking.
                    </p>
                    <p>Ai nevoie de ajutor? Contactează-ne la <a href="mailto:office@smartship.ro">office@smartship.ro</a> sau pe <a href="https://smartship.ro">Smartship.ro</a></p>
                    <p>Versiunea: ' . $this->version . ' <span id="smartship-version"></span> </p>
                </div>

            </div>
        </div>
        <div id="smartship-awb-modal">
          <div class="modal-content">
            <span class="close" id="smartship-awb-close">&times;</span>
            <div class="form-section-inner">
                <div class="">
                    <form id="smartship-awb-form">
                        <label>Nume</label>
                        <input type="text" name="name" value="' . htmlspecialchars($receiver_name) . '" required />
                        <label>Telefon</label>
                        <input type="text" name="phone" value="' . htmlspecialchars($receiver_phone) . '" required />
                        <label>Email</label>
                        <input type="email" name="email" value="' . htmlspecialchars($receiver_email) . '" required />
                        <div class="form-row">
                        <div><label>Județ</label><input type="text" style="margin-bottom: 0px;" name="county" value="' . htmlspecialchars($county) . '" required /></div>
                        <div class="location-field-container" style="position: relative; margin-bottom: 12px;">
                            <label>Localitate</label>
                            <input type="text" name="city" id="city-input" style="margin-bottom: 0px;" value="' . htmlspecialchars($city) . '" required autocomplete="off" />
                            <div id="dropdownContent" class="hidden absolute left-0 right-0  bg-white border border-gray-300 rounded-lg shadow-lg z-50" style="display: none; position: absolute; left: 0; right: 0; background: white; border: 1px solid #ccc; border-radius: 8px; box-shadow: 0 4px 12px rgba(0,0,0,0.15); z-index: 1000;">    
                                <div id="locationResults" class="max-h-60 overflow-y-auto" style="max-height: 240px; overflow-y: auto;">
                                    <!-- Results will be populated here -->
                                </div>
                            </div>
                            <div id="location-error" class="error-message" style="display: none; color: #dc3545; font-size: 12px; margin-top: 4px;">Localitatea nu a fost găsită. Vă rugăm să selectați din listă.</div>
                        </div>
                        </div>
                        <label>Sector</label>
                        <select name="sector" id="sector-select" style="margin-bottom: 12px;">
                            <option value="0">Fara sector</option>
                            <option value="1">Sector 1</option>
                            <option value="2">Sector 2</option>
                            <option value="3">Sector 3</option>
                            <option value="4">Sector 4</option>
                            <option value="5">Sector 5</option>
                        </select>
                        <label>Adresă</label>
                        <input type="text" name="address" value="' . htmlspecialchars($full_address) . '" required />
                        <div class="form-row">
                        <div><label>Colete</label><input type="number" name="colete" value="' . htmlspecialchars($colete) . '" min="1" required /></div>
                        <div><label>Greutate (kg)</label><input type="number" name="greutate" value="' . htmlspecialchars($total_weight) . '" min="1" step="1" required /></div>
                        <div><label>Ramburs (lei)</label><input type="number" name="ramburs" value="' . htmlspecialchars($ramburs) . '" min="0" step="0.01" required style="color:#e00;" /></div>
                        </div>
                        <div class="form-row">
                        <div><label>Lungime (cm)</label><input type="number" name="lungime" value="' . htmlspecialchars($max_depth) . '" min="1" required /></div>
                        <div><label>Latime (cm)</label><input type="number" name="latime" value="' . htmlspecialchars($max_width) . '" min="1" required /></div>
                        <div><label>Inaltime (cm)</label><input type="number" name="inaltime" value="' . htmlspecialchars($max_height) . '" min="1" required /></div>
                        </div>
                        <button type="submit" class="btn btn-success awb-btn calculate-btn">Calculează Cost</button>
                        <button type="button" class="btn btn-primary awb-btn edit-btn" style="display:none;">Editează Datele</button>
                        <div class="error-message"></div>
                    </form>
                </div>
                <div class="couriers-section">
                    <h3>Curieri Disponibili</h3>
                    <div class="loading-spinner">
                        <i class="icon-spinner"></i>
                        <p>Se caută curieri disponibili...</p>
                    </div>
                    <div id="couriers-list"></div>
                    <button type="button" class="btn btn-primary awb-btn" id="generate-awb-btn" style="display:none;">Generează AWB</button>
                </div>
            </div>
            
          </div>
        </div>
        <script>
        document.addEventListener("DOMContentLoaded", function() {
          var btn = document.getElementById("smartship-generate-awb");
          var modal = document.getElementById("smartship-awb-modal");
          var close = document.getElementById("smartship-awb-close");
          var form = document.getElementById("smartship-awb-form");
          var couriersSection = document.querySelector(".couriers-section");
          var couriersList = document.getElementById("couriers-list");
          var generateAwbBtn = document.getElementById("generate-awb-btn");
          var errorMessage = document.querySelector(".error-message");
          var selectedCourier = null;
          var loadingSpinner = document.querySelector(".loading-spinner");
          
          // Location search functionality
          var cityInput = document.getElementById("city-input");
          var dropdownContent = document.getElementById("dropdownContent");

          var locationResults = document.getElementById("locationResults");
          var locationError = document.getElementById("location-error");
          var searchTimeout = null;
          var validLocations = [];

          
          // Show dropdown when city input is focused
          cityInput.addEventListener("focus", function() {
            if (cityInput.value.length >= 2) {
              searchLocations(cityInput.value);
            }
          });
          
          // Handle city input changes
          cityInput.addEventListener("input", function() {
            clearTimeout(searchTimeout);
            locationError.style.display = "none";
            
            if (cityInput.value.length >= 2) {
              searchTimeout = setTimeout(function() {
                searchLocations(cityInput.value);
              }, 300);
            } else {
              dropdownContent.style.display = "none";
            }
          });
          
          // Handle location search input
         
          
          // Close dropdown when clicking outside
          document.addEventListener("click", function(event) {
            if (!event.target.closest(".location-field-container")) {
              dropdownContent.style.display = "none";
            }
          });
          
          // Function to search locations
          function searchLocations(searchTerm) {
            fetch("' . $this->context->link->getModuleLink('smartship', 'api', ['action' => 'search_localitati']) . '&search=" + encodeURIComponent(searchTerm))
              .then(response => response.json())
              .then(data => {
                if (data.status === 200 && data.locations) {
                  validLocations = data.locations;
                  displayLocations(data.locations);
                  dropdownContent.style.display = "block";
                } else {
                  locationResults.innerHTML = "<div style=\"padding: 12px; color: #666;\">Nu s-au găsit rezultate.</div>";
                  dropdownContent.style.display = "block";
                }
              })
              .catch(error => {
                console.error("Location search error:", error);
                locationResults.innerHTML = "<div style=\"padding: 12px; color: #dc3545;\">Eroare la căutarea locațiilor.</div>";
                dropdownContent.style.display = "block";
              });
          }
          
          // Function to display locations
          function displayLocations(locations) {
            locationResults.innerHTML = "";
            
            if (locations.length === 0) {
              locationResults.innerHTML = "<div style=\"padding: 12px; color: #666;\">Nu s-au găsit rezultate.</div>";
              return;
            }
            
            locations.forEach(location => {
              var locationItem = document.createElement("div");
              locationItem.className = "location-item";
              locationItem.style.cssText = "padding: 8px 12px; cursor: pointer; border-bottom: 1px solid #eee; transition: background-color 0.2s;";
              locationItem.innerHTML = `
                <div style="font-weight: 500;">${location.localitate}</div>
                <div style="font-size: 12px; color: #666;">${location.judet}</div>
              `;
              
              locationItem.addEventListener("mouseenter", function() {
                this.style.backgroundColor = "#f8f9fa";
              });
              
              locationItem.addEventListener("mouseleave", function() {
                this.style.backgroundColor = "";
              });
              
              locationItem.addEventListener("click", function() {
                cityInput.value = location.localitate;
                dropdownContent.style.display = "none";
                locationError.style.display = "none";
                validLocations = [location];
              });
              
              locationResults.appendChild(locationItem);
            });
          }
          
          // Validate location before form submission
          form.addEventListener("submit", function(e) {
            e.preventDefault();
            
            // Validate location before proceeding - only if user has entered a city and validLocations has been populated
            var cityValue = cityInput.value.trim();
            var isValidLocation = true; // Default to true
            
            // Only validate if user has entered a city value AND validLocations has been populated (meaning user has interacted with location search)
            if (cityValue.length > 0 && validLocations.length > 0) {
              isValidLocation = validLocations.some(location => 
                location.localitate.toLowerCase() === cityValue.toLowerCase()
              );
            }
            
            if (!isValidLocation) {
              locationError.style.display = "block";
              cityInput.focus();
              return false;
            }
            
            locationError.style.display = "none";
            errorMessage.style.display = "none";
            couriersSection.style.display = "block";
            loadingSpinner.classList.add("active");
            couriersList.innerHTML = "";
            generateAwbBtn.style.display = "none";
            selectedCourier = null;
            
            var formData = new FormData(form);
            var data = {};
            formData.forEach((value, key) => data[key] = value);
            
            fetch("' . $this->context->link->getModuleLink('smartship', 'api', ['action' => 'estimare_cost']) . '", {
              method: "POST",
              headers: {
                "Content-Type": "application/json",
              },
              body: JSON.stringify(data)
            })
            .then(response => response.json())
            .then(result => {
              loadingSpinner.classList.remove("active");
              if (result.status === 200 && result.response && result.response.costs) {
                couriersList.innerHTML = "";
                form.querySelectorAll("input").forEach(input => {
                  input.readOnly = true;
                });
                form.querySelector(".calculate-btn").style.display = "none";
                form.querySelector(".edit-btn").style.display = "block";
                form.querySelector(".edit-btn").onclick = function() {
                  form.querySelectorAll("input").forEach(input => {
                    input.readOnly = false;
                    form.querySelector(".calculate-btn").style.display = "block";
                    form.querySelector(".edit-btn").style.display = "none";
                    couriersSection.style.display = "none";
                    generateAwbBtn.style.display = "none";
                    document.querySelectorAll(".courier-card").forEach(c => c.remove());
                  });
                  form.querySelector(".edit-btn").style.display = "none";
                };
                
                result.response.costs.forEach(courier => {
                  var card = document.createElement("div");
                  card.className = "courier-card";
                  card.innerHTML = `
                    <img src="${courier.courier_logo}" alt="${courier.courier_name}" class="courier-logo">
                    <div class="courier-info">
                      <div class="courier-name">${courier.courier_name}</div>
                      <div class="courier-price">${courier.cost} RON</div>
                      <div class="courier-delivery">Livrare în ${courier.delivery_date}</div>
                    </div>
                  `;
                  card.onclick = function() {
                    document.querySelectorAll(".courier-card").forEach(c => c.classList.remove("selected"));
                    card.classList.add("selected");
                    selectedCourier = courier;
                    generateAwbBtn.style.display = "block";
                  };
                  couriersList.appendChild(card);
                });
                couriersSection.style.display = "block";
              } else {
                errorMessage.textContent = result.message || "A apărut o eroare la calcularea costului. Va rugam sa ne contactati pe smartship.ro pentru a rezolva problema!";
                errorMessage.style.display = "block";
                console.error("Cost Estimation Error:", result);
              }
            })
            .catch(error => {
              loadingSpinner.classList.remove("active");
              errorMessage.textContent = "A apărut o eroare la comunicarea cu serverul.";
              errorMessage.style.display = "block";
              console.error("Cost Estimation Error:", error);
            });
          });

          btn.onclick = function() { 
            modal.style.display = "block";
            couriersSection.style.display = "none";
            generateAwbBtn.style.display = "none";
          }
          
          close.onclick = function() { 
            modal.style.display = "none";
            couriersSection.style.display = "none";
            generateAwbBtn.style.display = "none";
          }
          
          window.onclick = function(event) { 
            if (event.target == modal) { 
              modal.style.display = "none";
              couriersSection.style.display = "none";
              generateAwbBtn.style.display = "none";
            }
          }

          generateAwbBtn.onclick = function() {
            if (!selectedCourier) {
              errorMessage.textContent = "Vă rugăm să selectați un curier.";
              errorMessage.style.display = "block";
              return;
            }
            
            // Validate location before generating AWB - only if user has entered a city and validLocations has been populated
            var cityValue = cityInput.value.trim();
            var isValidLocation = true; // Default to true
            
            // Only validate if user has entered a city value AND validLocations has been populated (meaning user has interacted with location search)
            if (cityValue.length > 0 && validLocations.length > 0) {
              isValidLocation = validLocations.some(location => 
                location.localitate.toLowerCase() === cityValue.toLowerCase()
              );
            }
            
            if (!isValidLocation) {
              locationError.style.display = "block";
              cityInput.focus();
              return;
            }
            
            var formData = new FormData(form);
            var data = {};
            formData.forEach((value, key) => data[key] = value);
            data.courier_id = selectedCourier.courier_id;
            data.order_id = ' . $params['id_order'] . ';
            
            console.log("Generating AWB with data:", data);
            
            loadingSpinner.classList.add("active");
            errorMessage.style.display = "none";
            
            loadingSpinner.classList.add("active");
            loadingSpinner.querySelector("p").textContent = "Se creează AWB-ul...";
            couriersList.style.display = "none";
            generateAwbBtn.style.display = "none";
            
            fetch("' . $this->context->link->getModuleLink('smartship', 'api', ['action' => 'emite_awb']) . '", {
              method: "POST",
              headers: {
                "Content-Type": "application/json",
              },
              body: JSON.stringify(data)
            })
            .then(response => {
              console.log("Response status:", response.status);
              console.log("Response headers:", response.headers);
              return response.text().then(text => {
                console.log("Raw response:", text);
                try {
                  return text ? JSON.parse(text) : null;
                } catch (e) {
                  console.error("JSON parse error:", e);
                  throw new Error("Invalid JSON response: " + text);
                }
              });
            })
            .then(result => {
              loadingSpinner.classList.remove("active");
              loadingSpinner.querySelector("p").textContent = "Se caută curieri disponibili...";
              couriersList.style.display = "block";
              if (result && result.status === 200) {
                alert("AWB generat cu succes: " + result.awb);
                modal.style.display = "none";
                location.reload();
              } else {
                let errorMsg = result ? (result.message || "A apărut o eroare la generarea AWB-ului.") : "Empty response from server";
                if (result && result.debug) {
                  console.error("AWB Generation Error Details:", result.debug);
                  if (result.debug.request_data) {
                    console.error("Request Data:", result.debug.request_data);
                  }
                  if (result.debug.response) {
                    console.error("API Response:", result.debug.response);
                  }
                }
                errorMessage.textContent = errorMsg;
                errorMessage.style.display = "block";
              }
            })
            .catch(error => {
              loadingSpinner.classList.remove("active");
              errorMessage.textContent = "A apărut o eroare la comunicarea cu serverul: " + error.message;
              errorMessage.style.display = "block";
              console.error("AWB Generation Error:", error);
            });
          };

          // Version check functionality - server-side to avoid CORS
          function checkVersion() {
            var versionSpan = document.getElementById("smartship-version");
            if (!versionSpan) return;
            
            // Show loading state
            versionSpan.innerHTML = " <span style=\"color: #6c757d; font-style: italic;\">(se verifică...)</span>";
            
            // Use our own API endpoint to check version
            fetch("' . $this->context->link->getModuleLink('smartship', 'api', ['action' => 'check_version']) . '")
              .then(response => response.json())
              .then(data => {
                console.log("Version check data:", data);
                if (data.status === 1) {              
                  versionSpan.innerHTML = " <span style=\"color: #ff6b35; font-weight: 600;\">🔄 Actualizare disponibilă: " + data.latest_version + ". <br>Descarcă de aici: <a href=\"https://smartship.ro/integrari/prestashop\">aici</a>!</span>";
                } else if (data.status === 0) {
                  versionSpan.innerHTML = " <span style=\"color: #28a745; font-weight: 600;\">✅</span>";
                } else if (data.status === 2) {
                  versionSpan.innerHTML = " <span style=\"color: #6c757d; font-style: italic;\">Versiunea ta este mai nouă decât cea disponibilă. Te rugăm să ne contactezi pentru a te ajuta!</span>";
                }
              })
              .catch(error => {
                console.error("Version check error:", error);
                versionSpan.innerHTML = " <span style=\"color: #6c757d; font-style: italic;\">(verificare eșuată)</span>";
              });
          }
          
          // Run version check when page loads
          checkVersion();
        });
        </script>';
    return $awb_modal;
  }

  // API Endpoints
  public function handleApiRequest($action)
  {
    $api = new SmartshipApi($this);
    $api->handleApiRequest($action);
  }

  public function hookActionFrontControllerSetMedia()
  {
    if ($this->context->controller instanceof SmartshipApiModuleFrontController) {
      $this->context->controller->addJS($this->_path . 'views/js/api.js');
    }
  }
}

